mexec_boot

Function mexec_boot 

pub fn mexec_boot(mexec_resource: Unowned<'_, Resource>) -> Result<(), Status>
Performs an mexec boot.

This function will obtain the kernel and data ZBIs, prepare them, and then call the mexec syscall.

mexec_resource must be a handle to the mexec resource.

This function does not return on success. On failure, it returns a zx::Status.